# -*- coding: utf-8 -*-
# Copyright (c) 2015 Tomek Wójcik <tomek@bthlabs.pl>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

import codecs
import json

from fabric.api import local, task


def _load_appinfo(path):
    appinfo = None
    with codecs.open(path, 'r', 'utf-8') as appinfo_in_f:
        appinfo = json.loads(appinfo_in_f.read())

    return appinfo


@task
def build(emulator=None, phone=None):
    appinfo = _load_appinfo('appinfo.in.json')
    assert appinfo

    appinfo_site = _load_appinfo('appinfo.site.json')
    if appinfo_site:
        appinfo.update(appinfo_site)

    with open('appinfo.json', 'w') as appinfo_f:
        appinfo_f.write(json.dumps(appinfo, indent=4))

    local('pebble build')


@task
def emu(platform='basalt'):
    local('pebble install --emulator=%s' % platform)


@task
def phone(ip):
    local('pebble install --phone=%s' % ip)
